Share and Enjoy
---------------

``sc.blog`` would not have been possible without the contribution of the
following people:

- Héctor Velarde
- `Brendan Mitchell`_ (icon)

You can find an updated list of package contributors on `GitHub`_.

Development sponsored by `Simples Consultoria`_.

.. _`Brendan Mitchell`: http://www.theblogicon.com/
.. _`GitHub`: https://github.com/simplesconsultoria/sc.blog/contributors
.. _`Simples Consultoria`: http://www.simplesconsultoria.com.br/
